@@ -50,11 +50,11 @@ class MaildirSource(MaildirService, util.ComparableMixin):
         self.category = category
         self.repository = repository
         if prefix and not prefix.endswith("/"):
-            log.msg(("MaildirSource: you probably want your prefix=('{}') to end with a slash"
-                     ).format(prefix))
+            log.msg(f"MaildirSource: you probably want your prefix=('{prefix}') to end with "
+                    "a slash")
 
     def describe(self):
-        return "{} watching maildir '{}'".format(self.__class__.__name__, self.basedir)
+        return f"{self.__class__.__name__} watching maildir '{self.basedir}'"
 
     @defer.inlineCallbacks
     def messageReceived(self, filename):
@@ -67,7 +67,7 @@ class MaildirSource(MaildirService, util.ComparableMixin):
         if chdict:
             yield self.master.data.updates.addChange(src=str(src), **chdict)
         else:
-            log.msg("no change found in maildir file '{}'".format(filename))
+            log.msg(f"no change found in maildir file '{filename}'")
 
     def parse_file(self, fd, prefix=None):
         m = message_from_file(fd)
@@ -91,7 +91,7 @@ class CVSMaildirSource(MaildirSource):
         # local username is enough to identify them (this assumes a one-server
         # cvs-over-rsh environment rather than the server-dirs-shared-over-NFS
         # model)
-        name, addr = parseaddr(m["from"])
+        _, addr = parseaddr(m["from"])
         if not addr:
             # no From means this message isn't from buildbot-cvs-mail
             return None
@@ -226,10 +226,10 @@ class CVSMaildirSource(MaildirSource):
                 raise ValueError(
                     'CVSMaildirSource cvs 1.12 require path. Check cvs loginfo config')
         else:
-            raise ValueError('Expected cvsmode 1.11 or 1.12. got: {}'.format(cvsmode))
+            raise ValueError(f'Expected cvsmode 1.11 or 1.12. got: {cvsmode}')
 
-        log.msg("CVSMaildirSource processing filelist: {}".format(fileList))
-        while(fileList):
+        log.msg(f"CVSMaildirSource processing filelist: {fileList}")
+        while fileList:
             m = singleFileRE.match(fileList)
             if m:
                 curFile = path + '/' + m.group(1)
@@ -246,11 +246,20 @@ class CVSMaildirSource(MaildirSource):
         comments = comments.rstrip() + "\n"
         if comments == '\n':
             comments = None
-        return ('cvs', dict(author=author, committer=None, files=files, comments=comments,
-                            isdir=isdir, when=when, branch=branch,
-                            revision=rev, category=category,
-                            repository=cvsroot, project=project,
-                            properties=self.properties))
+        return ('cvs', {
+            "author": author,
+            "committer": None,
+            "files": files,
+            "comments": comments,
+            "isdir": isdir,
+            "when": when,
+            "branch": branch,
+            "revision": rev,
+            "category": category,
+            "repository": cvsroot,
+            "project": project,
+            "properties": self.properties
+        })
 
 # svn "commit-email.pl" handler.  The format is very similar to freshcvs mail;
 # here's a sample:
@@ -289,7 +298,7 @@ class SVNCommitEmailMaildirSource(MaildirSource):
         # local username is enough to identify them (this assumes a one-server
         # cvs-over-rsh environment rather than the server-dirs-shared-over-NFS
         # model)
-        name, addr = parseaddr(m["from"])
+        _, addr = parseaddr(m["from"])
         if not addr:
             return None  # no From means this message isn't from svn
         at = addr.find("@")
@@ -332,7 +341,7 @@ class SVNCommitEmailMaildirSource(MaildirSource):
             # source server's expected TZ setting! messy.
 
             # this stanza ends with the "Log:"
-            if (line == "Log:\n"):
+            if line == "Log:\n":
                 break
 
         # commit message is terminated by the file-listing section
@@ -363,8 +372,8 @@ class SVNCommitEmailMaildirSource(MaildirSource):
                     if f.startswith(prefix):
                         f = f[len(prefix):]
                     else:
-                        log.msg(("ignored file from svn commit: prefix '{}' "
-                                 "does not match filename '{}'").format(prefix, f))
+                        log.msg(f"ignored file from svn commit: prefix '{prefix}' "
+                                f"does not match filename '{f}'")
                         continue
 
                 # TODO: figure out how new directories are described, set
@@ -375,8 +384,14 @@ class SVNCommitEmailMaildirSource(MaildirSource):
             log.msg("no matching files found, ignoring commit")
             return None
 
-        return ('svn', dict(author=author, committer=None, files=files, comments=comments,
-                            when=when, revision=rev))
+        return ('svn', {
+            "author": author,
+            "committer": None,
+            "files": files,
+            "comments": comments,
+            "when": when,
+            "revision": rev
+        })
 
 # bzr Launchpad branch subscription mails. Sample mail:
 #
@@ -440,20 +455,20 @@ class BzrLaunchpadEmailMaildirSource(MaildirSource):
             d['comments'] += s + "\n"
 
         def gobble_removed(s):
-            d['files'].append('{} REMOVED'.format(s))
+            d['files'].append(f'{s} REMOVED')
 
         def gobble_added(s):
-            d['files'].append('{} ADDED'.format(s))
+            d['files'].append(f'{s} ADDED')
 
         def gobble_modified(s):
-            d['files'].append('{} MODIFIED'.format(s))
+            d['files'].append(f'{s} MODIFIED')
 
         def gobble_renamed(s):
             match = re.search(r"^(.+) => (.+)$", s)
             if match:
-                d['files'].append('{} RENAMED {}'.format(match.group(1), match.group(2)))
+                d['files'].append(f'{match.group(1)} RENAMED {match.group(2)}')
             else:
-                d['files'].append('{} RENAMED'.format(s))
+                d['files'].append(f'{s} RENAMED')
 
         lines = list(body_line_iterator(m, True))
         rev = None
@@ -501,7 +516,7 @@ class BzrLaunchpadEmailMaildirSource(MaildirSource):
         if self.branchMap and repository:
             if repository in self.branchMap:
                 branch = self.branchMap[repository]
-            elif ("lp:" + repository) in self.branchMap:
+            elif "lp:" + repository in self.branchMap:
                 branch = self.branchMap['lp:' + repository]
         if not branch:
             if self.defaultBranch:
@@ -513,10 +528,16 @@ class BzrLaunchpadEmailMaildirSource(MaildirSource):
                     branch = None
 
         if rev and author:
-            return ('bzr', dict(author=author, committer=None, files=d['files'],
-                                comments=d['comments'],
-                                when=when, revision=rev,
-                                branch=branch, repository=repository or ''))
+            return ('bzr', {
+                "author": author,
+                "committer": None,
+                "files": d['files'],
+                "comments": d['comments'],
+                "when": when,
+                "revision": rev,
+                "branch": branch,
+                "repository": repository or ''
+            })
         return None
 
 
