@@ -23,13 +23,14 @@ from buildbot.www.rest import BadJsonRpc2
 
 
 def forceScheduler2Data(sched):
-    ret = dict(all_fields=[],
-               name=str(sched.name),
-               button_name=str(sched.buttonName),
-               label=str(sched.label),
-               builder_names=[str(name)
-                              for name in sched.builderNames],
-               enabled=sched.enabled)
+    ret = {
+        "all_fields": [],
+        "name": str(sched.name),
+        "button_name": str(sched.buttonName),
+        "label": str(sched.label),
+        "builder_names": [str(name) for name in sched.builderNames],
+        "enabled": sched.enabled
+    }
     ret["all_fields"] = [field.getSpec() for field in sched.all_fields]
     return ret
 
@@ -97,7 +98,7 @@ class ForceScheduler(base.ResourceType):
     name = "forcescheduler"
     plural = "forceschedulers"
     endpoints = [ForceSchedulerEndpoint, ForceSchedulersEndpoint]
-    keyFields = []
+    keyField = "name"
 
     class EntityType(types.Entity):
         name = types.Identifier(50)
@@ -106,4 +107,4 @@ class ForceScheduler(base.ResourceType):
         builder_names = types.List(of=types.Identifier(50))
         enabled = types.Boolean()
         all_fields = types.List(of=types.JsonObject())
-    entityType = EntityType(name)
+    entityType = EntityType(name, 'Forcescheduler')
