@@ -15,11 +15,10 @@
 
 
 import copy
+import math
 import random
 from datetime import datetime
 
-from dateutil.tz import tzutc
-
 from twisted.internet import defer
 from twisted.python import log
 from twisted.python.failure import Failure
@@ -27,8 +26,10 @@ from twisted.python.failure import Failure
 from buildbot.data import resultspec
 from buildbot.process import metrics
 from buildbot.process.buildrequest import BuildRequest
+from buildbot.util import deferwaiter
 from buildbot.util import epoch2datetime
 from buildbot.util import service
+from buildbot.util.async_sort import async_sort
 
 
 class BuildChooserBase:
@@ -226,11 +227,12 @@ class BasicBuildChooser(BuildChooserBase):
                     nextBreq = None
             except Exception:
                 log.err(Failure(),
-                        "from _getNextUnclaimedBuildRequest for builder '{}'".format(self.bldr))
+                        f"from _getNextUnclaimedBuildRequest for builder '{self.bldr}'")
                 nextBreq = None
         else:
-            # otherwise just return the first build
-            brdict = self.unclaimedBrdicts[0]
+            # otherwise just return the build with highest priority
+            brdict = sorted(self.unclaimedBrdicts.data,
+                            key=lambda b: b['priority'], reverse=True)[0]
             nextBreq = yield self._getBuildRequestForBrdict(brdict)
 
         return nextBreq
@@ -247,7 +249,7 @@ class BasicBuildChooser(BuildChooserBase):
                 worker = yield self.nextWorker(self.bldr, self.workerpool, buildrequest)
             except Exception:
                 log.err(Failure(),
-                        "from nextWorker for builder '{}'".format(self.bldr))
+                        f"from nextWorker for builder '{self.bldr}'")
                 worker = None
 
             if not worker or worker not in self.workerpool:
@@ -295,7 +297,7 @@ class BuildRequestDistributor(service.AsyncMultiService):
         self.activity_lock = defer.DeferredLock()
         self.active = False
 
-        self._pendingMSBOCalls = []
+        self._deferwaiter = deferwaiter.DeferWaiter()
         self._activity_loop_deferred = None
 
     @defer.inlineCallbacks
@@ -310,8 +312,7 @@ class BuildRequestDistributor(service.AsyncMultiService):
         # they don't get interrupted in mid-stride.  This tends to be
         # particularly painful because it can occur when a generator is gc'd.
         # TEST-TODO: this behavior is not asserted in any way.
-        if self._pendingMSBOCalls:
-            yield defer.DeferredList(self._pendingMSBOCalls)
+        yield self._deferwaiter.wait()
 
     @defer.inlineCallbacks
     def maybeStartBuildsOn(self, new_builders):
@@ -326,15 +327,10 @@ class BuildRequestDistributor(service.AsyncMultiService):
         if not self.running:
             return
 
-        d = self._maybeStartBuildsOn(new_builders)
-        self._pendingMSBOCalls.append(d)
-
         try:
-            yield d
+            yield self._deferwaiter.add(self._maybeStartBuildsOn(new_builders))
         except Exception as e:  # pragma: no cover
-            log.err(e, "while starting builds on {0}".format(new_builders))
-        finally:
-            self._pendingMSBOCalls.remove(d)
+            log.err(e, f"while starting builds on {new_builders}")
 
     @defer.inlineCallbacks
     def _maybeStartBuildsOn(self, new_builders):
@@ -363,8 +359,7 @@ class BuildRequestDistributor(service.AsyncMultiService):
                 if not self.active:
                     self._activity_loop_deferred = self._activityLoop()
             except Exception:  # pragma: no cover
-                log.err(Failure(),
-                        "while attempting to start builds on {}".format(self.name))
+                log.err(Failure(), f"while attempting to start builds on {self.name}")
 
         yield self.pending_builders_lock.run(
             resetPendingBuildersList, new_builders)
@@ -374,44 +369,28 @@ class BuildRequestDistributor(service.AsyncMultiService):
     def _defaultSorter(self, master, builders):
         timer = metrics.Timer("BuildRequestDistributor._defaultSorter()")
         timer.start()
-        # perform an asynchronous schwarzian transform, transforming None
-        # into sys.maxint so that it sorts to the end
 
-        def xform(bldr):
-            d = defer.maybeDeferred(bldr.getOldestRequestTime)
-            d.addCallback(lambda time:
-                          (((time is None) and None or time), bldr))
-            return d
-        xformed = yield defer.gatherResults(
-            [xform(bldr) for bldr in builders])
+        @defer.inlineCallbacks
+        def key(bldr):
+            # Sort primarily highest priority of build requests
+            priority = yield bldr.get_highest_priority()
+            if priority is None:
+                # for builders that do not have pending buildrequest, we just use large number
+                priority = -math.inf
+            # Break ties using the time of oldest build request
+            time = yield bldr.getOldestRequestTime()
+            if time is None:
+                # for builders that do not have pending buildrequest, we just use large number
+                time = math.inf
+            else:
+                if isinstance(time, datetime):
+                    time = time.timestamp()
+            return (-priority, time, bldr.name)
 
-        # sort the transformed list synchronously, comparing None to the end of
-        # the list
-        def xformedKey(a):
-            """
-            Key function can be used to sort a list
-            where each list element is a tuple:
-                (datetime.datetime, Builder)
+        yield async_sort(builders, key)
 
-            @return: a tuple of (date, builder name)
-            """
-            (date, builder) = a
-            if date is None:
-                # Choose a really big date, so that any
-                # date set to 'None' will appear at the
-                # end of the list during comparisons.
-                date = datetime.max
-                # Need to set the timezone on the date, in order
-                # to perform comparisons with other dates which
-                # have the time zone set.
-                date = date.replace(tzinfo=tzutc())
-            return (date, builder.name)
-        xformed.sort(key=xformedKey)
-
-        # and reverse the transform
-        rv = [xf[1] for xf in xformed]
         timer.stop()
-        return rv
+        return builders
 
     @defer.inlineCallbacks
     def _sortBuilders(self, buildernames):
@@ -432,7 +411,7 @@ class BuildRequestDistributor(service.AsyncMultiService):
 
         # run it
         try:
-            builders = yield defer.maybeDeferred(sorter, self.master, builders)
+            builders = yield sorter(self.master, builders)
         except Exception:
             log.err(Failure(), "prioritizing builders; order unspecified")
 
@@ -477,7 +456,7 @@ class BuildRequestDistributor(service.AsyncMultiService):
                 if bldr:
                     yield self._maybeStartBuildsOnBuilder(bldr)
             except Exception:
-                log.err(Failure(), "from maybeStartBuild for builder '{}'".format(bldr_name))
+                log.err(Failure(), f"from maybeStartBuild for builder '{bldr_name}'")
 
             self.activity_lock.release()
 
