@@ -31,6 +31,8 @@ from zope.interface import implementer
 from buildbot import config
 from buildbot import interfaces
 from buildbot import util
+from buildbot.config.checks import check_param_length
+from buildbot.db.model import Model
 from buildbot.interfaces import IRenderable
 from buildbot.interfaces import WorkerSetupError
 from buildbot.process import log as plog
@@ -48,7 +50,7 @@ from buildbot.process.results import RETRY
 from buildbot.process.results import SKIPPED
 from buildbot.process.results import SUCCESS
 from buildbot.process.results import WARNINGS
-from buildbot.process.results import Results
+from buildbot.process.results import statusToString
 from buildbot.util import bytes2unicode
 from buildbot.util import debounce
 from buildbot.util import flatten
@@ -139,8 +141,8 @@ class _BuildStepFactory(util.ComparableMixin):
         try:
             return self.factory(*self.args, **self.kwargs)
         except Exception:
-            log.msg("error while creating step, factory={}, args={}, kwargs={}".format(self.factory,
-                    self.args, self.kwargs))
+            log.msg(f"error while creating step, factory={self.factory}, args={self.args}, "
+                    f"kwargs={self.kwargs}")
             raise
 
 
@@ -240,13 +242,16 @@ class BuildStep(results.ResultComputingConfigMixin,
                 setattr(self, p, kwargs.pop(p))
 
         if kwargs:
-            config.error("{}.__init__ got unexpected keyword argument(s) {}".format(self.__class__,
-                                                                                    list(kwargs)))
+            config.error(f"{self.__class__}.__init__ got unexpected keyword argument(s) "
+                         f"{list(kwargs)}")
         self._pendingLogObservers = []
 
         if not isinstance(self.name, str) and not IRenderable.providedBy(self.name):
-            config.error("BuildStep name must be a string or a renderable object: "
-                         "%r" % (self.name,))
+            config.error(f"BuildStep name must be a string or a renderable object: "
+                         f"{repr(self.name)}")
+
+        check_param_length(self.name, f'Step {self.__class__.__name__} name',
+                           Model.steps.c.name.type.length)
 
         if isinstance(self.description, str):
             self.description = [self.description]
@@ -268,8 +273,8 @@ class BuildStep(results.ResultComputingConfigMixin,
             self.updateBuildSummaryPolicy = ALL_RESULTS
         if not isinstance(self.updateBuildSummaryPolicy, list):
             config.error("BuildStep updateBuildSummaryPolicy must be "
-                         "a list of result ids or boolean but it is %r" %
-                         (self.updateBuildSummaryPolicy,))
+                         "a list of result ids or boolean but it is "
+                         f"{repr(self.updateBuildSummaryPolicy)}")
         self._acquiringLocks = []
         self.stopped = False
         self.master = None
@@ -290,8 +295,8 @@ class BuildStep(results.ResultComputingConfigMixin,
         args = [repr(x) for x in self._factory.args]
         args.extend([str(k) + "=" + repr(v)
                      for k, v in self._factory.kwargs.items()])
-        return "{}({})".format(
-            self.__class__.__name__, ", ".join(args))
+        return f'{self.__class__.__name__}({", ".join(args)})'
+
     __repr__ = __str__
 
     def setBuild(self, build):
@@ -365,7 +370,7 @@ class BuildStep(results.ResultComputingConfigMixin,
             stepsumm = 'finished'
 
         if self.results != SUCCESS:
-            stepsumm += ' ({})'.format(Results[self.results])
+            stepsumm += f' ({statusToString(self.results)})'
 
         return {'step': stepsumm}
 
@@ -397,8 +402,7 @@ class BuildStep(results.ResultComputingConfigMixin,
 
         stepResult = summary.get('step', 'finished')
         if not isinstance(stepResult, str):
-            raise TypeError("step result string must be unicode (got %r)"
-                            % (stepResult,))
+            raise TypeError(f"step result string must be unicode (got {repr(stepResult)})")
         if self.stepid is not None:
             stepResult = self.build.properties.cleanupTextFromSecrets(
                 stepResult)
@@ -434,14 +438,14 @@ class BuildStep(results.ResultComputingConfigMixin,
 
         # then narrow WorkerLocks down to the worker that this build is being
         # run on
-        self.locks = [(l.getLockForWorker(self.build.workerforbuilder.worker),
+        self.locks = [(l.getLockForWorker(self.build.workerforbuilder.worker.workername),
                        la)
                       for l, la in self.locks]
 
-        for l, la in self.locks:
+        for l, _ in self.locks:
             if l in self.build.locks:
-                log.msg(("Hey, lock {} is claimed by both a Step ({}) and the"
-                         " parent Build ({})").format(l, self, self.build))
+                log.msg(f"Hey, lock {l} is claimed by both a Step ({self}) and the"
+                        f" parent Build ({self.build})")
                 raise RuntimeError("lock claimed by both Step and Build")
 
         try:
@@ -523,8 +527,6 @@ class BuildStep(results.ResultComputingConfigMixin,
                 self.results = EXCEPTION
                 hidden = False
 
-        yield self.master.data.updates.finishStep(self.stepid, self.results,
-                                                  hidden)
         # perform final clean ups
         success = yield self._cleanup_logs()
         if not success:
@@ -540,8 +542,15 @@ class BuildStep(results.ResultComputingConfigMixin,
 
         self.releaseLocks()
 
+        yield self.master.data.updates.finishStep(self.stepid, self.results,
+                                                  hidden)
+
         return self.results
 
+    def setBuildData(self, name, value, source):
+        # returns a Deferred that yields nothing
+        return self.master.data.updates.setBuildData(self.build.buildid, name, value, source)
+
     @defer.inlineCallbacks
     def _cleanup_logs(self):
         all_success = True
@@ -581,7 +590,7 @@ class BuildStep(results.ResultComputingConfigMixin,
             return defer.succeed(None)
         if self.stopped:
             return defer.succeed(None)
-        log.msg("acquireLocks(step {}, locks {})".format(self, self.locks))
+        log.msg(f"acquireLocks(step {self}, locks {self.locks})")
         for lock, access in self.locks:
             for waited_lock, _, _ in self._acquiringLocks:
                 if lock is waited_lock:
@@ -589,7 +598,7 @@ class BuildStep(results.ResultComputingConfigMixin,
 
             if not lock.isAvailable(self, access):
                 self._waitingForLocks = True
-                log.msg("step {} waiting for lock {}".format(self, lock))
+                log.msg(f"step {self} waiting for lock {lock}")
                 d = lock.waitUntilMaybeAvailable(self, access)
                 self._acquiringLocks.append((lock, access, d))
                 d.addCallback(self.acquireLocks)
@@ -608,9 +617,25 @@ class BuildStep(results.ResultComputingConfigMixin,
         warn_deprecated('3.0.0', 'BuildStep.isNewStyle() always returns True')
         return True
 
+    @defer.inlineCallbacks
+    def _maybe_interrupt_cmd(self, reason):
+        if not self.cmd:
+            return
+
+        try:
+            yield self.cmd.interrupt(reason)
+        except Exception as e:
+            log.err(e, 'while cancelling command')
+
+    @defer.inlineCallbacks
     def interrupt(self, reason):
         if self.stopped:
+            # If we are in the process of interruption and connection is lost then we must tell
+            # the command not to wait for the interruption to complete.
+            if isinstance(reason, Failure) and reason.check(error.ConnectionLost):
+                yield self._maybe_interrupt_cmd(reason)
             return
+
         self.stopped = True
         if self._acquiringLocks:
             for (lock, access, d) in self._acquiringLocks:
@@ -618,17 +643,15 @@ class BuildStep(results.ResultComputingConfigMixin,
             self._acquiringLocks = []
 
         if self._waitingForLocks:
-            self.addCompleteLog(
+            yield self.addCompleteLog(
                 'cancelled while waiting for locks', str(reason))
         else:
-            self.addCompleteLog('cancelled', str(reason))
+            yield self.addCompleteLog('cancelled', str(reason))
 
-        if self.cmd:
-            d = self.cmd.interrupt(reason)
-            d.addErrback(log.err, 'while cancelling command')
+        yield self._maybe_interrupt_cmd(reason)
 
     def releaseLocks(self):
-        log.msg("releaseLocks({}): {}".format(self, self.locks))
+        log.msg(f"releaseLocks({self}): {self.locks}")
         for lock, access in self.locks:
             if lock.isOwner(self, access):
                 lock.release(self, access)
@@ -651,7 +674,7 @@ class BuildStep(results.ResultComputingConfigMixin,
 
     def checkWorkerHasCommand(self, command):
         if not self.workerVersion(command):
-            message = "worker is too old, does not know about {}".format(command)
+            message = f"worker is too old, does not know about {command}"
             raise WorkerSetupError(message)
 
     def getWorkerName(self):
@@ -837,7 +860,7 @@ class ShellMixin:
             prohibitArgs = []
 
         def bad(arg):
-            config.error("invalid {} argument {}".format(self.__class__.__name__, arg))
+            config.error(f"invalid {self.__class__.__name__} argument {arg}")
         for arg in self._shellMixinArgs:
             if arg not in constructorArgs:
                 continue
@@ -892,8 +915,10 @@ class ShellMixin:
 
         # merge the builder's environment with that supplied here
         builderEnv = self.build.builder.config.env
-        kwargs['env'] = yield self.build.render(builderEnv)
-        kwargs['env'].update(self.env)
+        kwargs['env'] = {
+            **(yield self.build.render(builderEnv)),
+            **kwargs['env'],
+        }
         kwargs['stdioLogName'] = stdioLogName
 
         # default the workdir appropriately
@@ -913,7 +938,7 @@ class ShellMixin:
         # set up logging
         if stdio is not None:
             cmd.useLog(stdio, False)
-        for logname, remotefilename in self.logfiles.items():
+        for logname in self.logfiles:
             if self.lazylogfiles:
                 # it's OK if this does, or does not, return a Deferred
                 def callback(cmd_arg, local_logname=logname):
@@ -933,7 +958,7 @@ class ShellMixin:
         summary = util.command_to_string(self.command)
         if summary:
             if self.results != SUCCESS:
-                summary += ' ({})'.format(Results[self.results])
+                summary += f' ({statusToString(self.results)})'
             return {'step': summary}
         return super().getResultSummary()
 
