@@ -18,6 +18,7 @@ from urllib.parse import urlparse
 from twisted.internet import defer
 from twisted.python import log
 
+from buildbot import config
 from buildbot.process.properties import Properties
 from buildbot.process.properties import Property
 from buildbot.process.results import SUCCESS
@@ -41,9 +42,11 @@ _GET_TOKEN_DATA = {
 class BitbucketStatusPush(ReporterBase):
     name = "BitbucketStatusPush"
 
-    def checkConfig(self, oauth_key, oauth_secret, base_url=_BASE_URL, oauth_url=_OAUTH_URL,
-                    debug=None, verify=None, status_key=None, status_name=None,
-                    generators=None, **kwargs):
+    def checkConfig(self, oauth_key=None, oauth_secret=None, auth=None, base_url=_BASE_URL,
+                    oauth_url=_OAUTH_URL, debug=None, verify=None, status_key=None,
+                    status_name=None, generators=None, **kwargs):
+        if auth is not None and (oauth_key is not None or oauth_secret is not None):
+            config.error('Either App Passwords or OAuth can be specified, not both')
 
         if generators is None:
             generators = self._create_default_generators()
@@ -52,10 +55,11 @@ class BitbucketStatusPush(ReporterBase):
         httpclientservice.HTTPClientService.checkAvailable(self.__class__.__name__)
 
     @defer.inlineCallbacks
-    def reconfigService(self, oauth_key, oauth_secret, base_url=_BASE_URL, oauth_url=_OAUTH_URL,
-                        debug=None, verify=None, status_key=None, status_name=None,
-                        generators=None, **kwargs):
+    def reconfigService(self, oauth_key=None, oauth_secret=None, auth=None, base_url=_BASE_URL,
+                        oauth_url=_OAUTH_URL, debug=None, verify=None, status_key=None,
+                        status_name=None, generators=None, **kwargs):
         oauth_key, oauth_secret = yield self.renderSecrets(oauth_key, oauth_secret)
+        self.auth = yield self.renderSecrets(auth)
         self.base_url = base_url
         self.debug = debug
         self.verify = verify
@@ -71,11 +75,13 @@ class BitbucketStatusPush(ReporterBase):
 
         self._http = yield httpclientservice.HTTPClientService.getService(
             self.master, base_url,
-            debug=self.debug, verify=self.verify)
+            debug=self.debug, verify=self.verify, auth=self.auth)
 
-        self.oauthhttp = yield httpclientservice.HTTPClientService.getService(
-            self.master, oauth_url, auth=(oauth_key, oauth_secret),
-            debug=self.debug, verify=self.verify)
+        self.oauthhttp = None
+        if self.auth is None:
+            self.oauthhttp = yield httpclientservice.HTTPClientService.getService(
+                self.master, oauth_url, auth=(oauth_key, oauth_secret),
+                debug=self.debug, verify=self.verify)
 
     def _create_default_generators(self):
         return [
@@ -87,13 +93,15 @@ class BitbucketStatusPush(ReporterBase):
 
     @defer.inlineCallbacks
     def sendMessage(self, reports):
-        request = yield self.oauthhttp.post("", data=_GET_TOKEN_DATA)
-        if request.code != 200:
-            content = yield request.content()
-            log.msg(f"{request.code}: unable to authenticate to Bitbucket {content}")
-            return
-        token = (yield request.json())['access_token']
-        self._http.updateHeaders({'Authorization': f'Bearer {token}'})
+        # Only use OAuth if basic auth has not been specified
+        if not self.auth:
+            request = yield self.oauthhttp.post("", data=_GET_TOKEN_DATA)
+            if request.code != 200:
+                content = yield request.content()
+                log.msg(f"{request.code}: unable to authenticate to Bitbucket {content}")
+                return
+            token = (yield request.json())['access_token']
+            self._http.updateHeaders({'Authorization': f'Bearer {token}'})
 
         build = reports[0]['builds'][0]
         if build['complete']:
