@@ -16,6 +16,9 @@
 HVAC based providers
 """
 
+
+import pkg_resources
+
 from twisted.internet import defer
 from twisted.internet import threads
 
@@ -105,6 +108,7 @@ class HashiCorpVaultKvSecretProvider(SecretProviderBase):
         if vault_server.endswith('/'):  # pragma: no cover
             vault_server = vault_server[:-1]
         self.client = hvac.Client(vault_server)
+        self.version = pkg_resources.parse_version(pkg_resources.get_distribution('hvac').version)
         self.client.secrets.kv.default_kv_version = api_version
         return self
 
@@ -140,6 +144,10 @@ class HashiCorpVaultKvSecretProvider(SecretProviderBase):
         if self.api_version == 1:
             return self.client.secrets.kv.v1.read_secret(path=path, mount_point=self.secrets_mount)
         else:
+            if self.version >= pkg_resources.parse_version("1.1.1"):
+                return self.client.secrets.kv.v2.read_secret_version(path=path,
+                                                                     mount_point=self.secrets_mount,
+                                                                     raise_on_deleted_version=True)
             return self.client.secrets.kv.v2.read_secret_version(path=path,
                                                                  mount_point=self.secrets_mount)
 
