@@ -16,7 +16,7 @@
 import os
 import sys
 import warnings
-from pkg_resources import parse_version
+from unittest import mock
 
 import setuptools  # force import setuptools before any other distutils imports
 
@@ -25,24 +25,14 @@ from buildbot.test.util.warnings import assertProducesWarning  # noqa pylint: di
 from buildbot.test.util.warnings import assertProducesWarnings  # noqa pylint: disable=wrong-import-position
 from buildbot.warnings import DeprecatedApiWarning  # noqa pylint: disable=wrong-import-position
 
-# import mock so we bail out early if it's not installed
-try:
-    import mock
-    [mock]
-except ImportError as e:
-    raise ImportError("\nBuildbot tests require the 'mock' module; "
-                      "try 'pip install mock'") from e
+[mock]
 
 # apply the same patches the buildmaster does when it starts
-monkeypatches.patch_all(for_tests=True)
+monkeypatches.patch_all()
 
 # enable deprecation warnings
 warnings.filterwarnings('always', category=DeprecationWarning)
 
-if parse_version(mock.__version__) < parse_version("0.8"):
-    raise ImportError("\nBuildbot tests require mock version 0.8.0 or "
-                      "higher; try 'pip install -U mock'")
-
 [setuptools]  # force use for pylint
 
 # This is where we load deprecated module-level APIs to ignore warning produced by importing them.
@@ -72,10 +62,6 @@ warnings.filterwarnings('ignore', "1300 Invalid utf8 character string")
 # twisted.compat.execfile is using 'U' https://twistedmatrix.com/trac/ticket/9023
 warnings.filterwarnings('ignore', "'U' mode is deprecated", DeprecationWarning)
 
-# sqlalchemy.migrate is calling inspect.getargspec()
-# https://bugs.launchpad.net/sqlalchemy-migrate/+bug/1662472
-warnings.filterwarnings('ignore', r"inspect.getargspec\(\) is deprecated")
-
 # twisted.python.filepath and trial are using bytes file paths when
 # the "native" file path (Unicode) should be used on Windows.
 warnings.filterwarnings('ignore',
@@ -91,10 +77,6 @@ warnings.filterwarnings('ignore', r"The value of convert_charrefs will become Tr
 # Twisted 18.4+ adds a deprecation warning and still use the deprecated API in its own code!
 warnings.filterwarnings('ignore', ".*getClientIP was deprecated.*", DeprecationWarning)
 
-# Python 3.7 adds a deprecation warning formatargspec.
-# The signature api that replaces it is not available in 2.7
-warnings.filterwarnings('ignore', ".*`formatargspec` is deprecated.*", DeprecationWarning)
-
 # Python 3.7 adds a deprecation importing ABCs from collection.
 # Such imports are made in dependencies (e.g moto, werzeug, pyparsing)
 warnings.filterwarnings('ignore', ".*Using or importing the ABCs from 'collections'.*",
@@ -103,21 +85,21 @@ warnings.filterwarnings('ignore', ".*Using or importing the ABCs from 'collectio
 # more 3.7 warning from moto
 warnings.filterwarnings('ignore', r".*Use 'list\(elem\)' or iteration over elem instead.*",
                         DeprecationWarning)
+warnings.filterwarnings('ignore', r".*distutils Version classes are deprecated.*",
+                        DeprecationWarning)
 
 # ignore ResourceWarnings for unclosed sockets for the pg8000 driver on Python 3+ (tech debt: #4508)
 if sys.version_info[0] >= 3 and "pg8000" in os.getenv("BUILDBOT_TEST_DB_URL", ""):
     warnings.filterwarnings('ignore', ".*unclosed .*socket", ResourceWarning)
 
+# ignore ResourceWarnings when connecting to a HashiCorp vault via hvac in integration tests
+warnings.filterwarnings('ignore', r".*unclosed .*socket.*raddr=.*, 8200[^\d]", ResourceWarning)
+
 # Python 3.5-3.8 shows this warning
 warnings.filterwarnings('ignore', ".*the imp module is deprecated in favour of importlib*")
 
-# sqlalchemy-migrate uses deprecated api from sqlalchemy https://review.openstack.org/#/c/648072/
-warnings.filterwarnings('ignore', ".*Engine.contextual_connect.*", DeprecationWarning)
-
-warnings.filterwarnings('ignore', r'.*The Table.exists\(\) method is deprecated.*',
-                        DeprecationWarning)
-warnings.filterwarnings('ignore', '.*is already present in table.*',
-                        DeprecationWarning)
+# Python 3.3-3.7 show this warning and in invoked from autobahn
+warnings.filterwarnings('ignore', ".*time.clock has been deprecated in Python 3.3.*")
 
 # ignore an attrs API warning for APIs used in dependencies
 warnings.filterwarnings('ignore', ".*The usage of `cmp` is deprecated and will be removed "
@@ -134,3 +116,34 @@ warnings.filterwarnings('ignore', ".*Not importing directory .*/sphinxcontrib: m
 # https://github.com/pypa/setuptools/issues/2086
 warnings.filterwarnings('ignore', ".*lib2to3 package is deprecated",
                         category=PendingDeprecationWarning)
+
+# on python 3.9, this warning is generated by the stdlib
+warnings.filterwarnings('ignore', ".*The loop argument is deprecated since Python",
+                        category=DeprecationWarning)
+
+# This warning is generated by the EC2 latent
+warnings.filterwarnings('ignore', ".*stream argument is deprecated. Use stream parameter",
+                        category=DeprecationWarning)
+
+# Botocore imports deprecated urllib3.contrib.pyopenssl for backwards compatibility that we don't
+# use. See https://github.com/boto/botocore/issues/2744
+warnings.filterwarnings('ignore', ".*'urllib3.contrib.pyopenssl' module is deprecated",
+                        category=DeprecationWarning)
+
+# pipes is still used in astroid and buildbot_worker in default installation
+warnings.filterwarnings('ignore', "'pipes' is deprecated and slated for removal in Python 3.13",
+                        category=DeprecationWarning)
+
+# shown on Python 3.7 on Windows
+warnings.filterwarnings('ignore', "SelectableGroups dict interface is deprecated. Use select.",
+                        category=DeprecationWarning)
+
+# shown on Python 3.11
+warnings.filterwarnings('ignore', ".*pkg_resources is deprecated as an API.*",
+                        category=DeprecationWarning)
+warnings.filterwarnings('ignore', ".*Deprecated call to `pkg_resources.declare_namespace.*",
+                        category=DeprecationWarning)
+
+# boto3 shows this warning when on old Python
+warnings.filterwarnings('ignore', ".*Boto3 will no longer support Python .*",
+                        category=Warning)
