@@ -26,7 +26,7 @@ from buildbot.worker import AbstractLatentWorker
 
 try:
     from buildbot_worker.bot import LocalWorker as RemoteWorker
-    from buildbot_worker.base import BotBase
+    from buildbot_worker.pb import BotPbLike
 except ImportError:
     RemoteWorker = None
 
@@ -56,6 +56,7 @@ class LatentController(SeverWorkerConnectionMixin):
                  starts_without_substantiate=None, **kwargs):
         self.case = case
         self.build_wait_timeout = build_wait_timeout
+        self.has_crashed = False
         self.worker = ControllableLatentWorker(name, self, **kwargs)
         self.remote_worker = None
 
@@ -164,7 +165,7 @@ class LatentController(SeverWorkerConnectionMixin):
         return self._started_kind
 
     def patchBot(self, case, remoteMethod, patch):
-        case.patch(BotBase, remoteMethod, patch)
+        case.patch(BotPbLike, remoteMethod, patch)
 
 
 class ControllableLatentWorker(AbstractLatentWorker):
@@ -226,3 +227,6 @@ class ControllableLatentWorker(AbstractLatentWorker):
             return True
         self._controller._stop_deferred = defer.Deferred()
         return (yield self._controller._stop_deferred)
+
+    def check_instance(self):
+        return not self._controller.has_crashed
