@@ -47,7 +47,12 @@ def cancelAfter(seconds, deferred, _reactor=reactor):
 
 
 def writeLocalFile(path, contents, mode=None):  # pragma: no cover
-    with open(path, 'w') as file:
+    with open(path, 'w', encoding='utf-8') as file:
         if mode is not None:
             os.chmod(path, mode)
         file.write(contents)
+
+
+def chunkify_list(l, chunk_size):
+    chunk_size = max(1, chunk_size)
+    return (l[i:i + chunk_size] for i in range(0, len(l), chunk_size))
