@@ -14,11 +14,11 @@
 # Copyright Buildbot Team Members
 
 from twisted.internet import defer
+from twisted.logger import Logger
 
 from buildbot.interfaces import LatentWorkerFailedToSubstantiate
 from buildbot.util import kubeclientservice
 from buildbot.util.latent import CompatibleLatentWorkerMixin
-from buildbot.util.logger import Logger
 from buildbot.worker.docker import DockerBaseWorker
 
 log = Logger()
@@ -110,7 +110,7 @@ class KubeLatentWorker(CompatibleLatentWorkerMixin,
             yield self._kube.createPod(self.namespace, pod_spec)
         except kubeclientservice.KubeError as e:
             raise LatentWorkerFailedToSubstantiate(str(e)) from e
-        defer.returnValue(True)
+        return True
 
     @defer.inlineCallbacks
     def stop_instance(self, fast=False, reportFailure=True):
