@@ -14,10 +14,12 @@
 # Copyright Buildbot Team Members
 
 
+import pkg_resources
 import re
 from abc import ABCMeta
 from abc import abstractmethod
 
+import twisted
 from twisted.cred.checkers import FilePasswordDB
 from twisted.cred.checkers import ICredentialsChecker
 from twisted.cred.checkers import InMemoryUsernamePasswordDatabaseDontUse
@@ -113,6 +115,15 @@ class RemoteUserAuth(AuthBase):
         if headerRegex is not None:
             self.headerRegex = re.compile(unicode2bytes(headerRegex))
 
+    def getLoginResource(self):
+        current_version = pkg_resources.parse_version(twisted.__version__)
+        if current_version < pkg_resources.parse_version("22.10.0"):
+            from twisted.web.resource import ForbiddenResource
+            return ForbiddenResource(message="URL is not supported for authentication")
+
+        from twisted.web.pages import forbidden
+        return forbidden(message="URL is not supported for authentication")
+
     @defer.inlineCallbacks
     def maybeAutoLogin(self, request):
         header = request.getHeader(self.header)
@@ -164,7 +175,7 @@ class TwistedICredAuthBase(AuthBase):
 class HTPasswdAuth(TwistedICredAuthBase):
 
     def __init__(self, passwdFile, **kwargs):
-        super().__init__([DigestCredentialFactory(b"md5", b"buildbot"),
+        super().__init__([DigestCredentialFactory(b"MD5", b"buildbot"),
              BasicCredentialFactory(b"buildbot")],
             [FilePasswordDB(passwdFile)],
             **kwargs)
@@ -177,7 +188,7 @@ class UserPasswordAuth(TwistedICredAuthBase):
             users = {user: unicode2bytes(pw) for user, pw in users.items()}
         elif isinstance(users, list):
             users = [(user, unicode2bytes(pw)) for user, pw in users]
-        super().__init__([DigestCredentialFactory(b"md5", b"buildbot"),
+        super().__init__([DigestCredentialFactory(b"MD5", b"buildbot"),
              BasicCredentialFactory(b"buildbot")],
             [InMemoryUsernamePasswordDatabaseDontUse(**dict(users))],
             **kwargs)
@@ -199,7 +210,7 @@ class CustomAuth(TwistedICredAuthBase):
         return defer.fail(UnauthorizedLogin())
 
     @abstractmethod
-    def check_credentials(username, password):
+    def check_credentials(username, password):  # noqa pylint: disable=no-self-argument
         return False
 
 
@@ -220,7 +231,7 @@ class PreAuthenticatedLoginResource(LoginResource):
     @defer.inlineCallbacks
     def renderLogin(self, request):
         session = request.getSession()
-        session.user_info = dict(username=bytes2unicode(self.username))
+        session.user_info = {"username": bytes2unicode(self.username)}
         yield self.master.www.auth.updateUserInfo(request)
         raise _redirect(self.master, request)
 
